@@ -3,13 +3,17 @@
 """
 import json
 from palp import settings
-from palp.pipeline.pipeline_base import Pipeline
+from palp.pipeline.pipeline import Pipeline
 
 
-class ItemRecyclePipeline(Pipeline):
+class RedisRecyclePipeline(Pipeline):
+    """
+        对重试多次失败的 item 进行回收，放入 redis 失败队列
+    """
+
     def pipeline_failed(self, spider, item) -> None:
         """
-        对重试多次失败的 item 进行回收
+        回收失败的 item
 
         :param spider:
         :param item:
@@ -17,6 +21,9 @@ class ItemRecyclePipeline(Pipeline):
         """
         from palp.conn import redis_conn
 
+        if redis_conn is None:
+            return
+
         redis_conn.sadd(settings.REDIS_KEY_QUEUE_BAD_ITEM, json.dumps({
             'module': item.__class__.__module__,  # 引用自哪里
             'init': item.__class__.__name__,  # 引用的模块名
