@@ -6,12 +6,11 @@
 """
 import json
 import time
-import uuid
 import datetime
 import threading
 from loguru import logger
 from palp import settings
-from quickdb import RedisLockNoWait, RedisLock
+from quickdb import RedisLockNoWait
 
 
 class ClientHeart:
@@ -21,11 +20,8 @@ class ClientHeart:
         :param spider:
         """
         self.spider = spider
-
-        self.stop = False  # 停止标志（用于异常时）
         self.beating_time = 4  # 心跳频率
         self.check_time = self.beating_time - 1  # 心跳检查频率
-        self.client_name = self.generate_client_name()  # 随机客户端名
 
     def start(self):
         beating = threading.Thread(target=self.beating, daemon=True)
@@ -34,11 +30,8 @@ class ClientHeart:
         try:
             self.check_client_beating()
         except Exception as e:
-            self.stop = True
             self.spider.spider_master = False
             logger.exception(e)
-        finally:
-            self.close(beating)
 
     def check_client_beating(self):
         """
@@ -49,7 +42,7 @@ class ClientHeart:
         """
         from palp.conn import redis_conn
 
-        while not self.stop and not self.all_client_is_waiting:
+        while not self.all_client_is_waiting:
 
             all_client_is_waiting = True
 
@@ -82,7 +75,7 @@ class ClientHeart:
 
                             if master_detail and master_detail['name'] == client_name:
                                 self.spider.spider_master = True
-                                master_detail['name'] = self.client_name
+                                master_detail['name'] = self.spider.spider_uuid
                                 redis_conn.set(settings.REDIS_KEY_MASTER, json.dumps(master_detail, ensure_ascii=False))
                     else:
                         if client_name in failed_client:
@@ -110,7 +103,7 @@ class ClientHeart:
         """
         from palp.conn import redis_conn
 
-        while not self.stop and not self.all_client_is_waiting:
+        while True:
             # 检测是否分发完毕
             heart = {
                 "time": int(time.time()),
@@ -124,24 +117,11 @@ class ClientHeart:
             # 设置 redis 心跳
             redis_conn.hset(
                 settings.REDIS_KEY_HEARTBEAT,
-                self.client_name,
+                self.spider.spider_uuid,
                 json.dumps(heart, ensure_ascii=False)
             )
             time.sleep(self.beating_time)
 
-    def close(self, beating: threading.Thread):
-        """
-        清理资源
-
-        :return:
-        """
-        from palp.conn import redis_conn
-
-        while True:
-            if not beating.is_alive():
-                redis_conn.hdel(settings.REDIS_KEY_HEARTBEAT, self.client_name)
-                break
-
     @staticmethod
     def master_distribute_thread_is_done() -> bool:
         """
@@ -153,9 +133,13 @@ class ClientHeart:
         from palp.conn import redis_conn
 
         master_detail = json.loads(redis_conn.get(settings.REDIS_KEY_MASTER).decode())
-        res = redis_conn.hget(settings.REDIS_KEY_HEARTBEAT, master_detail['name']).decode()
+        res = redis_conn.hget(settings.REDIS_KEY_HEARTBEAT, master_detail['name'])
+        if res:
+            res = res.decode()  # 一定要判断，不然可能产生时间差，master 还没有心跳，但是已经开始检测心跳
 
-        return json.loads(res)['distribute_done']
+            return json.loads(res)['distribute_done']
+
+        return False
 
     @staticmethod
     def stop_all_client():
@@ -178,49 +162,3 @@ class ClientHeart:
         from palp.conn import redis_conn
 
         return bool(redis_conn.exists(settings.REDIS_KEY_STOP))
-
-    @staticmethod
-    def remove_stop_status():
-        """
-        移除停止信号
-
-        :return:
-        """
-        from palp.conn import redis_conn
-
-        while True:
-            if not redis_conn.exists(settings.REDIS_KEY_HEARTBEAT):
-                redis_conn.delete(settings.REDIS_KEY_STOP)
-                break
-
-            time.sleep(0.1)
-
-    def generate_client_name(self) -> str:
-        """
-        生成客户端的名字
-
-        :return:
-        """
-        from palp.conn import redis_conn
-
-        while True:
-            name = str(uuid.uuid1())
-            with RedisLock(conn=redis_conn, lock_name=settings.REDIS_KEY_LOCK + 'GenerateHeart', block_timeout=10):
-                if redis_conn.hget(settings.REDIS_KEY_HEARTBEAT, name):
-                    continue
-                else:
-
-                    # master 重新起名字
-                    if self.spider.spider_master:
-                        master_detail = json.loads(redis_conn.get(settings.REDIS_KEY_MASTER).decode())
-                        master_detail['name'] = name
-                        redis_conn.set(settings.REDIS_KEY_MASTER, json.dumps(master_detail, ensure_ascii=False))
-
-                    # 发送起始心跳
-                    redis_conn.hset(settings.REDIS_KEY_HEARTBEAT, name, json.dumps({
-                        "time": int(time.time()),
-                        "waiting": False,  # 是否所有线程没事干
-                        'distribute_done': False,  # 任务分发是否结束
-                    }, ensure_ascii=False))
-
-                    return name
